summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kcautoconfigmodule.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kcautoconfigmodule.h')
-rw-r--r--kopete/libkopete/kcautoconfigmodule.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kopete/libkopete/kcautoconfigmodule.h b/kopete/libkopete/kcautoconfigmodule.h
index d09173ea..9102f2b4 100644
--- a/kopete/libkopete/kcautoconfigmodule.h
+++ b/kopete/libkopete/kcautoconfigmodule.h
@@ -39,8 +39,8 @@ class KConfig;
* typedef KGenericFactory<MyPageConfig, TQWidget> MyPageConfigFactory;
* K_EXPORT_COMPONENT_FACTORY( kcm_mypageconfig, MyPageConfigFactory( "kcm_mypageconfig" ) )
*
* MyPageConfig( TQWidget * tqparent, const char *, const TQStringList & args )
* : KCAutoConfigModule( MyPageConfigFactory::instance(), tqparent, args )
* {
* setMainWidget( new MyPageConfigBase(this) , "MyGroup" );
* }
@@ -58,40 +58,40 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Standard KCModule constructor. Use KGlobal::config()
*/
- KCAutoConfigModule( TQWidget * tqparent = 0, const char * name = 0, const TQStringList & args = TQStringList() );
+ KCAutoConfigModule( TQWidget * parent = 0, const char * name = 0, const TQStringList & args = TQStringList() );
/**
* Standard KCModule constructor. Use KGlobal::config()
*/
- KCAutoConfigModule( KInstance * instance, TQWidget * tqparent = 0, const TQStringList & args = TQStringList() );
+ KCAutoConfigModule( KInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
/**
* Constructor.
* @param config the KConfig to use
* @param instance KInstance object for this KCM
* @param tqparent tqparent widget
* @param args special arguments for this KCM
*
* @todo document what the args mean (inherited from KCModule?)
*/
- KCAutoConfigModule(KConfig* config, KInstance * instance, TQWidget * tqparent = 0, const TQStringList & args = TQStringList() );
+ KCAutoConfigModule(KConfig* config, KInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
/**
* Constructor, much like the one above, except with
* no instance and with a name.
* @param config the KConfig to use
* @param tqparent tqparent widget
* @param name name of the object
* @param args special arguments for this KCM
*/
- KCAutoConfigModule(KConfig* config, TQWidget * tqparent = 0, const char * name=0 , const TQStringList & args = TQStringList() );
+ KCAutoConfigModule(KConfig* config, TQWidget * parent = 0, const char * name=0 , const TQStringList & args = TQStringList() );
~KCAutoConfigModule();
/**
* Set the main widget. @p widget will be lay out to take all available place in the module.
* @p widget must have this module as tqparent.
*
* This method automatically call KAutoConfig::addWidget() and KAutoConfig::retrieveSettings()
*
@@ -114,7 +114,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Reload the config from the configfile.
*
* You can also reimplement this method, but you should always call the tqparent KCModule::load()
* be sure you know what you are doing
*/
virtual void load();
@@ -122,7 +122,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Save the config to the configfile.
*
* You can also reimplement this method, but you should always call the tqparent KCModule::save()
* be sure you know what you are doing
*/
virtual void save();
@@ -130,7 +130,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Reload the default config
*
* You can also reimplement this method, but you should always call the tqparent KCModule::defaults()
* be sure you know what you are doing
*/
virtual void defaults();
@@ -39,8 +39,8 @@ class KConfig;
* K_EXPORT_COMPONENT_FACTORY( kcm_mypageconfig, MyPageConfigFactory( "kcm_mypageconfig" ) )
*
- * MyPageConfig( TQWidget * tqparent, const char *, const TQStringList & args )
- * : KCAutoConfigModule( MyPageConfigFactory::instance(), tqparent, args )
+ * MyPageConfig( TQWidget * parent, const char *, const TQStringList & args )
+ * : KCAutoConfigModule( MyPageConfigFactory::instance(), parent, args )
* {
* setMainWidget( new MyPageConfigBase(this) , "MyGroup" );
@@ -58,40 +58,40 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* @param config the KConfig to use
* @param instance KInstance object for this KCM
- * @param tqparent tqparent widget
+ * @param parent parent widget
* @param args special arguments for this KCM
*
@@ -58,40 +58,40 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* no instance and with a name.
* @param config the KConfig to use
- * @param tqparent tqparent widget
+ * @param parent parent widget
* @param name name of the object
* @param args special arguments for this KCM
@@ -58,40 +58,40 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Set the main widget. @p widget will be lay out to take all available place in the module.
- * @p widget must have this module as tqparent.
+ * @p widget must have this module as parent.
*
* This method automatically call KAutoConfig::addWidget() and KAutoConfig::retrieveSettings()
@@ -114,7 +114,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* Reload the config from the configfile.
*
- * You can also reimplement this method, but you should always call the tqparent KCModule::load()
+ * You can also reimplement this method, but you should always call the parent KCModule::load()
* be sure you know what you are doing
*/
@@ -122,7 +122,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* Save the config to the configfile.
*
- * You can also reimplement this method, but you should always call the tqparent KCModule::save()
+ * You can also reimplement this method, but you should always call the parent KCModule::save()
* be sure you know what you are doing
*/
@@ -130,7 +130,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* Reload the default config
*
- * You can also reimplement this method, but you should always call the tqparent KCModule::defaults()
+ * You can also reimplement this method, but you should always call the parent KCModule::defaults()
* be sure you know what you are doing
*/